% Pre-located from function libiers_admint because of speed; now the admittance 
% and frequency is compute only once for all three coordinate components
% 
% 
% Input
%   TAMP    amplitudes of the 11 main tides generated by Bos-Scherneck
%           website (Radial, West, South) [m]
%   TPH     phases of the 11 main tides from Bos-Scherneck website (RWS)[deg]
%   TAMPT   Cartwright-Edden amplitudes for the 11 main tides
%   IDT     Doodson numbers of the 11 tides
%   mjd
%   leap
% 
% Output
%   RF      frequency
%   RL, AIM real and imaginary parts of admittance, scaled by Cartwright-
%           Edden amplitude.
%
% 
% Coded for VieVS
% 18 July 2011 by Hana Spicakova


function [RF RL AIM] = libiers_admint_part1(TAMP, TPH, TAMPT, IDD, mjd, leap, index)

NIN=size(TAMP,2); %     NIN = 11
          
RL=zeros(1,NIN);
AIM=zeros(1,NIN);

% vertical (index = 1)
% west (index = 2)
% south (index = 3)
AMPIN = TAMP(index,:);
PHIN = TPH(index,:);
RL = AMPIN .* cos(deg2rad(PHIN))./abs(TAMPT);
AIM= AMPIN .* sin(deg2rad(PHIN))./abs(TAMPT);

% *+---------------------------------------------------------------------
% *  Now have real and imaginary parts of admittance, scaled by Cartwright-
% *  Edden amplitude. Admittance phase is whatever was used in the original
% *  expression. (Usually phase is given relative to some reference,
% *  but amplitude is in absolute units). Next get frequency.
% *----------------------------------------------------------------------
  for i=1 : NIN %11
     [FR PR] = libiers_tdfrph(IDD(i,:),mjd,leap);
      RF(i) = FR;
  end

% *+---------------------------------------------------------------------
% *  Done going through constituents; there are k of them.
% *  Have specified admittance at a number of points. Sort these by frequency
% *  and separate diurnal and semidiurnal, recopying admittances to get them
% *  in order using Shell Sort.
% *----------------------------------------------------------------------
    

[RF KEY]=sort(RF);

RL = RL(KEY); % sort real admittance
AIM = AIM(KEY);% sort imaginary part of admittance

